@@ -12,19 +12,134 @@ use Moo::Role;
 
 requires qw( add_leader config loc output );
 
+# Private functions
+my $_default_input = sub {
+   my ($fh, $args) = @_;
+
+   ($ENV{PERL_MM_USE_DEFAULT} or $ENV{PERL_MB_USE_DEFAULT})
+      and return $args->{default};
+   $args->{onechar} and return getc $fh;
+   return scalar <$fh>;
+};
+
+my $_get_control_chars = sub {
+   # Returns a string of pipe separated control
+   # characters and a hash of symbolic names and values
+   my $handle = shift; my %cntl = GetControlChars $handle;
+
+   return ((join '|', values %cntl), %cntl);
+};
+
+my $_justify_count = sub {
+   return pad $_[ 1 ], int log $_[ 0 ] / log 10, SPC, 'left';
+};
+
+my $_map_prompt_args = sub { # IO::Prompt equiv. sub has an obscure bug so this
+   my $args = shift; my %map = ( qw(-1 onechar -d default -e echo -p prompt) );
+
+   for (grep { exists $map{ $_ } } keys %{ $args }) {
+       $args->{ $map{ $_ } } = delete $args->{ $_ };
+   }
+
+   return $args;
+};
+
+my $_raw_mode = sub { # Puts the terminal in raw input mode
+   my $handle = shift; ReadMode 'raw', $handle; return;
+};
+
+my $_restore_mode = sub { # Restores line input mode to the terminal
+   my $handle = shift; ReadMode 'restore', $handle; return;
+};
+
+my $_prompt = sub {
+   # This was taken from L<IO::Prompt> which has an obscure bug in it
+   my $args    = $_map_prompt_args->( arg_list @_ );
+   my $default = $args->{default};
+   my $echo    = $args->{echo   };
+   my $onechar = $args->{onechar};
+   my $OUT     = \*STDOUT;
+   my $IN      = \*STDIN;
+   my $input   = NUL;
+
+   my ($len, $newlines, $next, $text);
+
+   IO::Interactive::is_interactive() or return $_default_input->( $IN, $args );
+
+   my ($cntl, %cntl) = $_get_control_chars->( $IN );
+   local $SIG{INT}   = sub { $_restore_mode->( $IN ); exit FAILED };
+
+   emit_to $OUT, $args->{prompt}; $_raw_mode->( $IN );
+
+   while (TRUE) {
+      if (defined ($next = getc $IN)) {
+         if ($next eq $cntl{INTERRUPT}) {
+            $_restore_mode->( $IN ); exit FAILED;
+         }
+         elsif ($next eq $cntl{ERASE}) {
+            if ($len = length $input) {
+               $input = substr $input, 0, $len - 1; emit_to $OUT, "\b \b";
+            }
+
+            next;
+         }
+         elsif ($next eq $cntl{EOF}) {
+            $_restore_mode->( $IN );
+            close $IN or throw 'IO error: [_1]', [ $OS_ERROR ];
+            return $input;
+         }
+         elsif ($next !~ m{ $cntl }mx) {
+            $input .= $next;
+
+            if ($next eq "\n") {
+               if ($input eq "\n" and defined $default) {
+                  $text = defined $echo ? $echo x length $default : $default;
+                  emit_to $OUT, "[${text}]\n"; $_restore_mode->( $IN );
+
+                  return $onechar ? substr $default, 0, 1 : $default;
+               }
+
+               $newlines .= "\n";
+            }
+            else { emit_to $OUT, $echo // $next }
+         }
+         else { $input .= $next }
+      }
+
+      if ($onechar or not defined $next or $input =~ m{ \Q$RS\E \z }mx) {
+         chomp $input; $_restore_mode->( $IN );
+         defined $newlines and emit_to $OUT, $newlines;
+         return $onechar ? substr $input, 0, 1 : $input;
+      }
+   }
+
+   return;
+};
+
+# Private methods
+my $_prepare = sub {
+   my ($self, $question) = @_; my $add_leader;
+
+   '+' eq substr $question, 0, 1 and $add_leader = TRUE
+      and $question = substr $question, 1;
+   $question = $self->loc( $question );
+   $add_leader and $question = $self->add_leader( $question );
+   return $question;
+};
+
 # Public methods
 sub anykey {
    my ($self, $prompt) = @_;
 
-   $prompt = $self->_prepare( $prompt || 'Press any key to continue' );
+   $prompt = $self->$_prepare( $prompt || 'Press any key to continue' );
 
-   return __prompt( -p => "${prompt}...", -d => TRUE, -e => NUL, -1 => TRUE );
+   return $_prompt->( -p => "${prompt}...", -d => TRUE, -e => NUL, -1 => TRUE );
 }
 
 sub get_line { # General text input routine.
    my ($self, $question, $default, $quit, $width, $multiline, $noecho) = @_;
 
-   $question  = $self->_prepare( $question || 'Enter your answer' );
+   $question  = $self->$_prepare( $question || 'Enter your answer' );
    $default //= NUL;
 
    my $advice       = $quit ? $self->loc( '([_1] to quit)', QUIT ) : NUL;
@@ -41,8 +156,8 @@ sub get_line { # General text input routine.
    my $prompt  = "${left_prompt} ${right_prompt}";
       $prompt .= ($multiline ? "\n[${default}]" : NUL).BRK;
    my $result  = $noecho
-               ? __prompt( -d => $default, -p => $prompt, -e => '*' )
-               : __prompt( -d => $default, -p => $prompt );
+               ? $_prompt->( -d => $default, -p => $prompt, -e => '*' )
+               : $_prompt->( -d => $default, -p => $prompt );
 
    $quit and defined $result and lc $result eq QUIT and exit FAILED;
 
@@ -60,7 +175,7 @@ sub get_option { # Select from an numbered list of options
 
    $self->output( $prompt, { no_lead => $no_lead } ); my $count = 1;
 
-   my $text = join "\n", map { __justify_count( $max, $count++ )." - ${_}" }
+   my $text = join "\n", map { $_justify_count->( $max, $count++ )." - ${_}" }
                             @{ $options };
 
    $self->output( $text, { cl => TRUE, nl => TRUE, no_lead => $no_lead } );
@@ -82,7 +197,7 @@ sub yorn { # General yes or no input routine
 
    my $no = NO; my $yes = YES; my $result;
 
-   $question = $self->_prepare( $question || 'Choose' );
+   $question = $self->$_prepare( $question || 'Choose' );
    $default  = $default ? $yes : $no; $quit = $quit ? QUIT : NUL;
 
    my $advice       = $quit ? "(${yes}/${no}, ${quit}) " : "(${yes}/${no}) ";
@@ -101,7 +216,7 @@ sub yorn { # General yes or no input routine
 
    $newline and $prompt .= "\n";
 
-   while ($result = __prompt( -d => $default, -p => $prompt )) {
+   while ($result = $_prompt->( -d => $default, -p => $prompt )) {
       $quit and $result =~ m{ \A (?: $quit | [\e] ) }imx and exit FAILED;
       $result =~ m{ \A $yes }imx and return TRUE;
       $result =~ m{ \A $no  }imx and return FALSE;
@@ -110,114 +225,6 @@ sub yorn { # General yes or no input routine
    return;
 }
 
-# Private methods
-sub _prepare {
-   my ($self, $question) = @_; my $add_leader;
-
-   '+' eq substr $question, 0, 1 and $add_leader = TRUE
-      and $question = substr $question, 1;
-   $question = $self->loc( $question );
-   $add_leader and $question = $self->add_leader( $question );
-   return $question;
-}
-
-# Private functions
-sub __get_control_chars {
-   my $handle = shift; my %cntl = GetControlChars $handle;
-
-   return ((join '|', values %cntl), %cntl);
-}
-
-sub __justify_count {
-   return pad $_[ 1 ], int log $_[ 0 ] / log 10, SPC, 'left';
-}
-
-sub __map_prompt_args { # IO::Prompt equiv. sub has an obscure bug so this
-   my $args = shift; my %map = ( qw(-1 onechar -d default -e echo -p prompt) );
-
-   for (grep { exists $map{ $_ } } keys %{ $args }) {
-       $args->{ $map{ $_ } } = delete $args->{ $_ };
-   }
-
-   return $args;
-}
-
-sub __prompt { # Robbed from IO::Prompt
-   my $args    = __map_prompt_args( arg_list @_ );
-   my $default = $args->{default};
-   my $echo    = $args->{echo   };
-   my $onechar = $args->{onechar};
-   my $OUT     = \*STDOUT;
-   my $IN      = \*STDIN;
-   my $input   = NUL;
-
-   my ($len, $newlines, $next, $text);
-
-   unless (IO::Interactive::is_interactive()) {
-      ($ENV{PERL_MM_USE_DEFAULT} or $ENV{PERL_MB_USE_DEFAULT})
-         and return $default;
-      $onechar and return getc $IN;
-      return scalar <$IN>;
-   }
-
-   my ($cntl, %cntl) = __get_control_chars( $IN );
-   local $SIG{INT}   = sub { __restore_mode( $IN ); exit FAILED };
-
-   emit_to $OUT, $args->{prompt}; __raw_mode( $IN );
-
-   while (TRUE) {
-      if (defined ($next = getc $IN)) {
-         if ($next eq $cntl{INTERRUPT}) {
-            __restore_mode( $IN ); exit FAILED;
-         }
-         elsif ($next eq $cntl{ERASE}) {
-            if ($len = length $input) {
-               $input = substr $input, 0, $len - 1; emit_to( $OUT, "\b \b" );
-            }
-
-            next;
-         }
-         elsif ($next eq $cntl{EOF}) {
-            __restore_mode( $IN );
-            close $IN or throw 'IO error: [_1]', args =>[ $OS_ERROR ];
-            return $input;
-         }
-         elsif ($next !~ m{ $cntl }mx) {
-            $input .= $next;
-
-            if ($next eq "\n") {
-               if ($input eq "\n" and defined $default) {
-                  $text = defined $echo ? $echo x length $default : $default;
-                  emit_to $OUT, "[${text}]\n"; __restore_mode( $IN );
-
-                  return $onechar ? substr $default, 0, 1 : $default;
-               }
-
-               $newlines .= "\n";
-            }
-            else { emit_to $OUT, $echo // $next }
-         }
-         else { $input .= $next }
-      }
-
-      if ($onechar or not defined $next or $input =~ m{ \Q$RS\E \z }mx) {
-         chomp $input; __restore_mode( $IN );
-         defined $newlines and emit_to $OUT, $newlines;
-         return $onechar ? substr $input, 0, 1 : $input;
-      }
-   }
-
-   return;
-}
-
-sub __raw_mode {
-   my $handle = shift; ReadMode 'raw', $handle; return;
-}
-
-sub __restore_mode {
-   my $handle = shift; ReadMode 'restore', $handle; return;
-}
-
 1;
 
 __END__
@@ -279,33 +286,6 @@ in the C<$question> argument
 
 Exposes L<IO::Interactive/is_interactive>
 
-=head2 __prompt
-
-   $line = __prompt( 'key' => 'value', ... );
-
-This was taken from L<IO::Prompt> which has an obscure bug in it. Much
-simplified the following keys are supported
-
-=over 3
-
-=item -1
-
-Return the first character typed
-
-=item -d
-
-Default response
-
-=item -e
-
-The character to echo in place of the one typed
-
-=item -p
-
-Prompt string
-
-=back
-
 =head2 yorn
 
    $self->yorn( $question, $default, $quit, $width );
@@ -317,25 +297,6 @@ included in the prompt. If the C<$width> argument is defined then the
 string is formatted to the specified width which is C<$width> or
 C<< $self->pwdith >> or 40
 
-=head2 __get_control_chars
-
-   ($cntrl, %cntrl) = __get_control_chars( $handle );
-
-Returns a string of pipe separated control characters and a hash of
-symbolic names and values
-
-=head2 __raw_mode
-
-   __raw_mode( $handle );
-
-Puts the terminal in raw input mode
-
-=head2 __restore_mode
-
-   __restore_mode( $handle );
-
-Restores line input mode to the terminal
-
 =head1 Diagnostics
 
 None
@@ -370,7 +331,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2014 Peter Flanigan. All rights reserved
+Copyright (c) 2015 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
